package main

import (
	"flag"
	"fmt"
	"github.com/kelseyhightower/envconfig"
	"log"
	"net/http"
)

var verbose = flag.Bool("verbose", false, "increase logging verbosity")

func main() {
	flag.Parse()
	log.SetFlags(log.Ldate | log.Ltime | log.Lshortfile)
	config := NewConfig()
	err := envconfig.Process("ITSLOG", config)
	if err != nil {
		log.Fatal(err)
	}
	if err := config.validate(); err != nil {
		log.Fatal(err)
	}
	log.Printf("%+v", config)

	http.Handle("/api/v0/info/", JsonHandler(apiInfo))

	err = http.ListenAndServe(fmt.Sprintf(":%d", config.Port), nil)
	if err != nil {
		log.Fatal(err)
	}
}
